@@ -24,7 +24,7 @@ class AgentCoreClient:
         self,
         probe_name: str,
         version: str,
-        checks: list,
+        checks: dict,
         read_asset_config: Optional[Callable] = None,
         config_fn: Optional[str] = None
     ):
@@ -37,6 +37,11 @@ class AgentCoreClient:
         self._probe_name = probe_name
         self._probe_version = version
         self._checks = checks
+        self._required_services = [
+            c.__name__
+            for c in checks.values()
+            if getattr(c, 'required', False)
+        ]
 
         config_fn = CONFIG_FN or config_fn
         config = json.load(open(config_fn)) if config_fn and \
@@ -132,7 +137,7 @@ class AgentCoreClient:
             'availableChecks': {
                 k: {
                     'defaultCheckInterval': v.interval,
-                    'requiredServices': [],  # not supported by agentcoreclient
+                    'requiredServices': self._required_services,
                 } for k, v in self._checks.items()
             },
         })
@@ -155,6 +160,22 @@ class AgentCoreClient:
         platform_bits = 'x64' if sys.maxsize > 2 ** 32 else 'x32'
         return f'{platform.system()}_{platform_bits}_{platform.release()}'
 
+    @staticmethod
+    def _get_framework(check, start_time: float, is_available: bool):
+        framework = {
+            'timestamp': start_time,
+            'runtime': time.time() - start_time
+        }
+        if getattr(check, 'required', False):
+            msg = 'OK' if is_available else 'see check error(s) for details'
+            framework['serviceInfo'] = {'services': {check.__name__: {
+                'available': is_available,
+                'reportedBy': check.__name__,
+                'serviceInfoMsg': msg,
+                'hasDependingChecks': True
+            }}}
+        return framework
+
     async def on_run_check(self, data):
         try:
             asset_id = data['hostUuid']
@@ -162,22 +183,22 @@ class AgentCoreClient:
             check_name = data['checkName']
             agentcore_uuid = asset_config['parentCore']
             config = asset_config['probeConfig'][self._probe_name]
-            ip4 = config['ip4']
-            check_func = self._checks[check_name].run
+            ip4 = config.get('ip4')
+            check = self._checks[check_name]
         except Exception:
             logging.error('invalid check configuration')
             return
 
-        cred = self._on_asset_config and get_asset_config(
+        cred: Optional[dict] = self._on_asset_config and get_asset_config(
             asset_id, ip4, agentcore_uuid, self._on_asset_config)
 
         t0 = time.time()
         try:
-            state_data = await check_func(data, cred)
+            state_data = await check.run(data, cred)
         except Exception as e:
             logging.warning(f'on_run_check {asset_id} {check_name} {e}')
             message = str(e)
-            framework = {'timestamp': t0, 'runtime': time.time() - t0}
+            framework = self._get_framework(check, t0, is_available=False)
             self.send({
                 'type': 'checkError',
                 'hostUuid': asset_id,
@@ -188,7 +209,7 @@ class AgentCoreClient:
         else:
             if state_data:
                 logging.debug(f'on_run_check {asset_id} {check_name} ok!')
-                framework = {'timestamp': t0, 'runtime': time.time() - t0}
+                framework = self._get_framework(check, t0, is_available=True)
                 self.send({
                     'type': 'stateData',
                     'hostUuid': asset_id,
